import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleBand,
  scaleLinear,
  max,
} from 'd3';
import { message } from './message.js';

const csvUrl =
  'https://gist.githubusercontent.com/curran/0ac4077c7fc6390f5dd33bf5c06cb5ff/raw/605c54080c7a93a417a3cea93fd52e7550e76500/UN_Population_2019.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 20,
  left: 200,
};

const App = () => {
  const [data, setData] = useState(null);
  const innerHeight =
    height - margin.top - margin.bottom;
  const innerWidth =
    width - margin.left - margin.right;
  useEffect(() => {
    const row = (d) => {
      d.Population = +d['2020'];
      return d;
    };
    d3.csv(csvUrl, row).then((data) => {
      setData(data.slice(0, 10));
    });
  }, [csvUrl]);
  if (!data) {
    return <pre>Loading ... </pre>;
  }
  const yScale = scaleBand()
    .domain(data.map((d) => d.Country))
    .range([0, innerHeight]);
  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.Population)])
    .range([0, innerWidth]);
  xScale.ticks().map((tickValue) => {
    console.log(tickValue);
    console.log(xScale);
    console.log(xScale(tickValue));
  });
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            key={tickValue}
            transform={`translate(${xScale(
              tickValue
            )},0)`}
          >
            <text
              dy=".71em"
              y={innerHeight + 3}
              style={{ textAnchor: ' middle' }}
            >
              {tickValue}
            </text>
            <line
              x1="0"
              x2="0"
              y1="0"
              y2={innerHeight}
              stroke="black"
            ></line>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            x="-3"
            y={
              yScale(tickValue) +
              yScale.bandwidth() / 2
            }
            dy=".32em"
            style={{ textAnchor: 'end' }}
          >
            {tickValue}
          </text>
        ))}
        {data.map((d, i) => {
          // console.log(yScale(d.Country))

          return (
            <rect
              key={d.Country}
              x={0}
              y={yScale(d.Country)}
              width={xScale(d.Population)}
              height={yScale.bandwidth()}
            />
          );
        })}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
